Advanced topics
===============

.. toctree::

    stochastic_dependencies
    generalized_polynomial_chaos
    advanced_regression_method
    kernel_density_estimation
    gaussian_mixture_model
    polynomial_chaos_kriging
    seir_model
